summaryrefslogtreecommitdiffstats
path: root/chrome/browser/views/find_bar_win_uitest.cc
diff options
context:
space:
mode:
authorpkasting@chromium.org <pkasting@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2008-12-08 20:50:05 +0000
committerpkasting@chromium.org <pkasting@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2008-12-08 20:50:05 +0000
commitf1d306e67b8676336f55aae95652d7cd51359534 (patch)
tree6f25205e78ba4c69e7b45468b3fdd0f6bed259f5 /chrome/browser/views/find_bar_win_uitest.cc
parentb3d565264e6073bd00e4dfd81c8f887ea01fb58c (diff)
downloadchromium_src-f1d306e67b8676336f55aae95652d7cd51359534.zip
chromium_src-f1d306e67b8676336f55aae95652d7cd51359534.tar.gz
chromium_src-f1d306e67b8676336f55aae95652d7cd51359534.tar.bz2
Cleanup, part 1.
* Consistently use underscores between words in identifiers (IDC_NEWTAB -> IDC_NEW_TAB) * Make some identifiers clearer or more up-to-date (IDC_DUPLICATE -> IDC_DUPLICATE_TAB, IDC_GOOFFTHERECORD -> IDC_NEW_INCOGNITO_WINDOW, IDC_NEWPROFILEWINDOW -> IDC_PROFILE_MENU) * Try and make string identifiers (IDS_xxx) match their corresponding IDC_xxx commands. Tony tells me this will not cause any need for retranslation. * As much as possible (without modifying automated UI test XML files), use "Bookmark Bar", not "Bookmarks Bar" (this seemed to be prevailing usage in the code) * Fix 80-column issues This patch touches move files than any subsequent patches, but should be the most rubber-stampable. Review URL: http://codereview.chromium.org/13633 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@6535 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/views/find_bar_win_uitest.cc')
-rw-r--r--chrome/browser/views/find_bar_win_uitest.cc6
1 files changed, 3 insertions, 3 deletions
diff --git a/chrome/browser/views/find_bar_win_uitest.cc b/chrome/browser/views/find_bar_win_uitest.cc
index 7350779..2354d72a 100644
--- a/chrome/browser/views/find_bar_win_uitest.cc
+++ b/chrome/browser/views/find_bar_win_uitest.cc
@@ -255,7 +255,7 @@ TEST_F(FindInPageControllerTest, FindMovesOnTabClose_Issue1343052) {
ASSERT_TRUE(browser.get() != NULL);
// Toggle the bookmark bar state.
- browser->ApplyAccelerator(IDC_SHOW_BOOKMARKS_BAR);
+ browser->ApplyAccelerator(IDC_SHOW_BOOKMARK_BAR);
EXPECT_TRUE(WaitForBookmarkBarVisibilityChange(browser.get(), true));
// Open the Find window and wait for it to animate.
@@ -280,8 +280,8 @@ TEST_F(FindInPageControllerTest, FindMovesOnTabClose_Issue1343052) {
EXPECT_EQ(x, new_x);
EXPECT_EQ(y, new_y);
- // Now reset the bookmarks bar state and try the same again.
- browser->ApplyAccelerator(IDC_SHOW_BOOKMARKS_BAR);
+ // Now reset the bookmark bar state and try the same again.
+ browser->ApplyAccelerator(IDC_SHOW_BOOKMARK_BAR);
EXPECT_TRUE(WaitForBookmarkBarVisibilityChange(browser.get(), false));
// Bookmark bar has moved, reset our coordinates.